<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Product;
use App\Models\Category;
use Illuminate\Http\Request;

class DashboardController extends Controller
{
    public function index()
    {
        // Get product statistics
        $totalProducts = Product::count();
        $totalCategories = Category::count();
        
        // Get pharmaceutical product statistics
        $tabletProducts = Product::where('type', 'Tablet')->count();
        $syrupProducts = Product::where('type', 'Syrup')->count();
        $capsuleProducts = Product::where('type', 'Capsule')->count();
        $otherProducts = Product::whereNotIn('type', ['Tablet', 'Syrup', 'Capsule'])->orWhereNull('type')->count();
        
        // Get recent products
        $recentProducts = Product::with('category')
            ->orderBy('created_at', 'desc')
            ->take(5)
            ->get();
        
        return view('admin.dashboard', compact(
            'totalProducts', 
            
            'totalCategories', 
            'recentProducts',
            'tabletProducts',
            'syrupProducts',
            'capsuleProducts',
            'otherProducts'
        ));
    }
}