@extends('layouts.admin')

@section('title', 'Create Product')

@section('content')
<div class="container-fluid">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h1 class="h3 mb-0 text-gray-800">Create New Product</h1>
        <a href="{{ route('admin.products.index') }}" class="btn btn-cancel">
            <i class="bi bi-arrow-left"></i> Back to Products
        </a>
    </div>

    <div class="form-container">
        <form action="{{ route('admin.products.store') }}" method="POST" enctype="multipart/form-data">
            @csrf
            @if ($errors->any())
    <div class="alert alert-danger">
        <strong>There were some problems with your submission.</strong>
        <ul class="mb-0 mt-2">
            @foreach ($errors->all() as $error)
                <li>{{ $error }}</li>
            @endforeach
        </ul>
    </div>
@endif
            {{-- Title --}}
            <div class="form-group">
                <label for="title" class="form-label">Product Title</label>
                <div class="form-group-with-icon">
                    <i class="bi bi-box"></i>
                    <input type="text" class="form-control @error('title') is-invalid @enderror" id="title" name="title" value="{{ old('title') }}" placeholder="Enter product name" required>
                </div>
                @error('title')
                    <div class="invalid-feedback">{{ $message }}</div>
                @enderror
            </div>

            {{-- Type & Packaging --}}
            <div class="row">
                <div class="col-md-6">
                    <div class="form-group">
                        <label for="type" class="form-label">Type</label>
                        <select class="form-select @error('type') is-invalid @enderror" id="type" name="type">
                            <option value="">Select a type</option>
                            @foreach($categories as $category)
                                <option value="{{ $category->id }}" {{ old('type') == $category->name ? 'selected' : '' }}>
                                    {{ $category->name }}
                                </option>
                            @endforeach
                        </select>
                        @error('type')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>

                <div class="col-md-6">
                    <div class="form-group">
                        <label for="packaging" class="form-label">Packaging</label>
                        <input type="text" class="form-control @error('packaging') is-invalid @enderror" id="packaging" name="packaging" value="{{ old('packaging') }}" placeholder="Enter packaging details">
                        @error('packaging')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>
            </div>

            {{-- Composition --}}
            <div class="form-group">
                <label for="composition" class="form-label">Composition</label>
                <textarea class="form-control @error('composition') is-invalid @enderror" id="composition" name="composition" rows="3" placeholder="Enter product composition">{{ old('composition') }}</textarea>
                @error('composition')
                    <div class="invalid-feedback">{{ $message }}</div>
                @enderror
            </div>

            {{-- Usages --}}
            <div class="form-group">
                <label for="usages" class="form-label">Usages</label>
                <textarea class="form-control @error('usages') is-invalid @enderror" id="usages" name="usages" rows="3" placeholder="Enter product usages">{{ old('usages') }}</textarea>
                @error('usages')
                    <div class="invalid-feedback">{{ $message }}</div>
                @enderror
            </div>

            {{-- MRP --}}
            <div class="form-group">
                <label for="mrp" class="form-label">MRP</label>
                <div class="form-group-with-icon">
                    <i class="bi bi-currency-dollar"></i>
                    <input type="number" step="0.01" class="form-control @error('mrp') is-invalid @enderror" id="mrp" name="mrp" value="{{ old('mrp') }}" placeholder="0.00">
                </div>
                @error('mrp')
                    <div class="invalid-feedback">{{ $message }}</div>
                @enderror
            </div>

            {{-- Image --}}
            <div class="form-group">
                <label for="image" class="form-label">Product Image</label>
                <input type="file" class="form-control @error('image_url') is-invalid @enderror" id="image_url" name="image_url" accept="image/*" required>
                @error('image')
                    <div class="invalid-feedback">{{ $message }}</div>
                @enderror
                <div class="form-text">Recommended size: 800x600 pixels. Max file size: 2MB.</div>
                <div id="imagePreview" class="mt-2" style="display: none;">
                    <img src="" alt="Preview" class="image-preview">
                </div>
            </div>

            {{-- Slug --}}
            <div class="form-group">
                <label for="slug" class="form-label">Slug</label>
                <input type="text" class="form-control @error('slug') is-invalid @enderror" id="slug" name="slug" value="{{ old('slug') }}" placeholder="Enter URL slug">
                @error('slug')
                    <div class="invalid-feedback">{{ $message }}</div>
                @enderror
            </div>

            {{-- Meta Title --}}
            <div class="form-group">
                <label for="meta_title" class="form-label">Meta Title</label>
                <input type="text" class="form-control @error('meta_title') is-invalid @enderror" id="meta_title" name="meta_title" value="{{ old('meta_title') }}" placeholder="Enter meta title">
                @error('meta_title')
                    <div class="invalid-feedback">{{ $message }}</div>
                @enderror
            </div>

            {{-- Meta Description --}}
            <div class="form-group">
                <label for="meta_description" class="form-label">Meta Description</label>
                <textarea class="form-control @error('meta_description') is-invalid @enderror" id="meta_description" name="meta_description" rows="3" placeholder="Enter meta description">{{ old('meta_description') }}</textarea>
                @error('meta_description')
                    <div class="invalid-feedback">{{ $message }}</div>
                @enderror
            </div>

            <div class="form-actions">
                <button type="submit" class="btn btn-submit">
                    <i class="bi bi-plus-circle"></i> Create Product
                </button>
            </div>

        </form>
    </div>
</div>


@push('scripts')
<script>
    // Image preview functionality
    document.getElementById('image').addEventListener('change', function(e) {
        const preview = document.getElementById('imagePreview');
        const previewImg = preview.querySelector('img');
        
        if (this.files && this.files[0]) {
            const reader = new FileReader();
            
            reader.onload = function(e) {
                previewImg.src = e.target.result;
                preview.style.display = 'block';
            }
            
            reader.readAsDataURL(this.files[0]);
        } else {
            preview.style.display = 'none';
        }
    });
</script>
@endpush
@endsection 