@extends('layouts.admin')

@section('title', 'Products')

@section('content')
<div class="container-fluid">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h1 class="h3 mb-0 text-gray-800">Products</h1>
        <a href="{{ route('admin.products.create') }}" class="btn btn-add">
            <i class="fas fa-plus"></i> Add New Product
        </a>
    </div>

    @if(session('success'))
        <div class="alert alert-success">
            {{ session('success') }}
        </div>
    @endif

    <div class="table-container">
        <div class="table-responsive">
        <table class="table">
                    <thead>
                            <tr>
                                <th>Image</th>
                                <th>Title</th>
                                <th>Type</th>
                                <th>Packaging</th>
                                <th>Composition</th>
                                <th>Usages</th>
                                <th>MRP</th>
                                <th>Meta Title</th>
                                <th>Meta Description</th>
                                <th>Slug</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                                                <tbody>
                            @forelse($products as $product)
                            <tr>
                                <td>
                                    @if($product->image_url)
                                        <img src="{{ asset($product->image_url) }}" alt="{{ $product->title }}" class="product-image" style="max-width: 100px; height: auto;">
                                    @else
                                        <div class="no-image">No Image</div>
                                    @endif
                                </td>
                                <td>{{ $product->title }}</td>
                                <td>
                                    <span class="badge {{ $product->type ? 'badge-primary' : 'badge-secondary' }}">
                                        {{ $product->type ?? 'Not Set' }}
                                    </span>
                                </td>
                                <td>{{ $product->packaging ?? 'N/A' }}</td>
                                <td>{{ Str::limit($product->composition, 50) }}</td>
                                <td>{{ Str::limit($product->usages, 50) }}</td>
                                <td>${{ number_format($product->mrp, 2) }}</td>
                                <td>{{ Str::limit($product->meta_title, 50) }}</td>
                                <td>{{ Str::limit($product->meta_description, 50) }}</td>
                                <td>{{ $product->slug }}</td>
                                <td>
                                    <a href="{{ route('admin.products.edit', $product) }}" class="btn btn-edit">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <form action="{{ route('admin.products.destroy', $product) }}" method="POST" class="d-inline">
                                        @csrf
                                        @method('DELETE')
                                        <button type="submit" class="btn btn-delete" onclick="return confirm('Are you sure?')">
                                            <i class="fas fa-trash"></i>
                                        </button>
                                    </form>
                                </td>
                            </tr>
                            @empty
                            <tr>
                                <td colspan="11" class="text-center">No products found.</td>
                            </tr>
                            @endforelse
                        </tbody>

                    </table>
        </div>

        <div class="d-flex justify-content-center mt-4">
            {{ $products->links() }}
        </div>
    </div>
</div>
@endsection 